@@ -1,7 +1,7 @@
 package Parse::PhoneNumber::ID;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use strict;
@@ -983,7 +983,7 @@ Parse::PhoneNumber::ID - Parse Indonesian phone numbers
 
 =head1 VERSION
 
-This document describes version 0.14 of Parse::PhoneNumber::ID (from Perl distribution Parse-PhoneNumber-ID), released on 2015-08-18.
+This document describes version 0.15 of Parse::PhoneNumber::ID (from Perl distribution Parse-PhoneNumber-ID), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -1027,9 +1027,8 @@ L<Parse::PhoneNumber>
 
 =head2 extract_id_phones(%args) -> any
 
-{en_US Extract phone number(s) from text}.
+Extract phone number(s) from text.
 
-{en_US 
 Extracts phone number(s) from text. Return an array of one or more parsed phone
 number structure (a hash). Understands the list of known area codes and cellular
 operators, as well as other information. Understands various syntax e.g.
@@ -1041,7 +1040,6 @@ Indonesian language, but should be quite suitable for any other normal text.
 
 Non-Indonesian phone numbers (e.g. +65 12 3456 7890) will still be extracted,
 but without any other detailed information other than country code.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -1049,30 +1047,26 @@ Arguments ('*' denotes required arguments):
 
 =item * B<default_area_code> => I<str>
 
-{en_US When encountering a number without area code, use this}.
+When encountering a number without area code, use this.
 
-{en_US 
 If you want to extract numbers that doesn't contain area code (e.g. 7123 4567),
 you'll need to provide this.
-}
 
 =item * B<level> => I<int> (default: 5)
 
-{en_US How hard should the function extract numbers (1-9)}.
+How hard should the function extract numbers (1-9).
 
-{en_US 
 The higher the level, the harder this function will try finding phone numbers,
 but the higher the risk of false positives will be. E.g. in text
 '123456789012345' with level=5 it will not find a phone number, but with level=9
 it might assume, e.g. 1234567890 to be a phone number. Normally leaving level at
 default level is fine.
-}
 
 =item * B<max_numbers> => I<int>
 
 =item * B<text>* => I<str>
 
-{en_US Text containing phone numbers to extract from}.
+Text containing phone numbers to extract from.
 
 =back
 
@@ -1081,9 +1075,8 @@ Return value:  (any)
 
 =head2 parse_id_phone(%args) -> any
 
-{en_US Alias for extract_id_phones(..., max_numbers=>1)->[0]}.
+Alias for extract_id_phones(..., max_numbers=>1)->[0].
 
-{en_US 
 Extracts phone number(s) from text. Return an array of one or more parsed phone
 number structure (a hash). Understands the list of known area codes and cellular
 operators, as well as other information. Understands various syntax e.g.
@@ -1095,7 +1088,6 @@ Indonesian language, but should be quite suitable for any other normal text.
 
 Non-Indonesian phone numbers (e.g. +65 12 3456 7890) will still be extracted,
 but without any other detailed information other than country code.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -1103,28 +1095,24 @@ Arguments ('*' denotes required arguments):
 
 =item * B<default_area_code> => I<str>
 
-{en_US When encountering a number without area code, use this}.
+When encountering a number without area code, use this.
 
-{en_US 
 If you want to extract numbers that doesn't contain area code (e.g. 7123 4567),
 you'll need to provide this.
-}
 
 =item * B<level> => I<int> (default: 5)
 
-{en_US How hard should the function extract numbers (1-9)}.
+How hard should the function extract numbers (1-9).
 
-{en_US 
 The higher the level, the harder this function will try finding phone numbers,
 but the higher the risk of false positives will be. E.g. in text
 '123456789012345' with level=5 it will not find a phone number, but with level=9
 it might assume, e.g. 1234567890 to be a phone number. Normally leaving level at
 default level is fine.
-}
 
 =item * B<text>* => I<str>
 
-{en_US Text containing phone numbers to extract from}.
+Text containing phone numbers to extract from.
 
 =back
 
